You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openwhisk.apache.org by ma...@apache.org on 2017/08/16 09:23:46 UTC

[incubator-openwhisk-performance] 06/22: Common docker setup

This is an automated email from the ASF dual-hosted git repository.

markusthoemmes pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-openwhisk-performance.git

commit 088d1f46a49b2a8f2c5af5af9693d7c142a91193
Author: Markus Thoemmes <ma...@de.ibm.com>
AuthorDate: Mon Apr 24 08:33:23 2017 +0200

    Common docker setup
---
 deploy.sh | 7 ++++++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/deploy.sh b/deploy.sh
index 15bf1f6..fd3ac97 100755
--- a/deploy.sh
+++ b/deploy.sh
@@ -1,6 +1,11 @@
 #!/bin/sh
 
-# checkout OpenWhisk latest
+# common docker setup
+sudo gpasswd -a travis docker
+sudo -E bash -c 'echo '\''DOCKER_OPTS="-H tcp://0.0.0.0:4243 -H unix:///var/run/docker.sock --storage-driver=overlay --userns-remap=default"'\'' > /etc/default/docker'
+sudo service docker restart
+
+# checkout openwhisk latest
 git clone --depth 1 https://github.com/openwhisk/openwhisk.git
 
 # install ansible

-- 
To stop receiving notification emails like this one, please contact
"commits@openwhisk.apache.org" <co...@openwhisk.apache.org>.